==============================
parse-requirements-not-suckily
==============================

Because srsly wtf :) :) :| :| :(

Usage
=====

    from parse_requirements_not_suckily import parse_requirements

Later that day... (in setup.py)

    install_requires=parse_requirements()

You be all like "wat no filler garbage code, like batteries included lol?" and I
be all like "yes"

License
=======

Copyright (c) 2016 Jon Robison

See included LICENSE for licensing information
